@@ -68,6 +68,77 @@ class UpdateGroupMembershipRequest(Base):
         self.__user_ids = value        
 
 
+class UserCoverage(Base):
+        
+    """Sales coverage for user"""
+
+    @camel_case_translate
+    def __init__(
+        self,
+        name: str,
+        email: str,
+        app: str = None,
+        phone: str = None,
+        guid: str = None
+    ):        
+        super().__init__()
+        self.app = app
+        self.phone = phone
+        self.name = name
+        self.email = email
+        self.guid = guid
+
+    @property
+    def app(self) -> str:
+        """Marquee application covered by sales person"""
+        return self.__app
+
+    @app.setter
+    def app(self, value: str):
+        self._property_changed('app')
+        self.__app = value        
+
+    @property
+    def phone(self) -> str:
+        """Coverage phone number"""
+        return self.__phone
+
+    @phone.setter
+    def phone(self, value: str):
+        self._property_changed('phone')
+        self.__phone = value        
+
+    @property
+    def name(self) -> str:
+        """Coverage name"""
+        return self.__name
+
+    @name.setter
+    def name(self, value: str):
+        self._property_changed('name')
+        self.__name = value        
+
+    @property
+    def email(self) -> str:
+        """Coverage email"""
+        return self.__email
+
+    @email.setter
+    def email(self, value: str):
+        self._property_changed('email')
+        self.__email = value        
+
+    @property
+    def guid(self) -> str:
+        """Coverage guid"""
+        return self.__guid
+
+    @guid.setter
+    def guid(self, value: str):
+        self._property_changed('guid')
+        self.__guid = value        
+
+
 class GroupResponse(Base):
         
     @camel_case_translate
