@@ -13,7 +13,7 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-
+import pandas as pd
 import pytest
 from pandas.util.testing import assert_series_equal
 
@@ -49,6 +49,11 @@ def test_last():
     expected = pd.Series([4.0, 4.0, 4.0, 4.0], index=dates)
     assert_series_equal(result, expected, obj="First")
 
+    y = pd.Series([1.0, 2.0, 3.0, np.nan], index=dates)
+    result = last(y)
+    expected = pd.Series([3.0, 3.0, 3.0, 3.0], index=dates)
+    assert_series_equal(result, expected, obj="Last non-NA")
+
 
 def test_last_value():
     with pytest.raises(MqValueError):
@@ -60,6 +65,9 @@ def test_last_value():
     y = pd.Series([5])
     assert last_value(y) == 5
 
+    y = pd.Series([1.0, 2.0, 3.0, np.nan], index=(pd.date_range("2020-01-01", periods=4, freq="D")))
+    assert last_value(y) == 3.0
+
 
 def test_count():
     dates = [
@@ -76,6 +84,58 @@ def test_count():
     assert_series_equal(result, expected, obj="Count")
 
 
+def test_compare():
+    dates1 = [
+        date(2019, 1, 1),
+        date(2019, 1, 2),
+        date(2019, 1, 3),
+        date(2019, 1, 4),
+    ]
+
+    dates2 = [
+        date(2019, 1, 1),
+        date(2019, 1, 2),
+        date(2019, 1, 3),
+    ]
+
+    x = pd.Series([1.0, 2.0, 2.0, 4.0], index=dates1)
+    y = pd.Series([2.0, 1.0, 2.0], index=dates2)
+
+    expected = pd.Series([-1.0, 1.0, 0.0], index=dates2)
+    result = compare(x, y, method=Interpolate.INTERSECT)
+    assert_series_equal(expected, result, obj="Compare series intersect")
+
+    expected = pd.Series([1.0, -1.0, 0], index=dates2)
+    result = compare(y, x, method=Interpolate.INTERSECT)
+    assert_series_equal(expected, result, obj="Compare series intersect 2")
+
+    expected = pd.Series([-1.0, 1.0, 0, 0], index=dates1)
+    result = compare(x, y, method=Interpolate.NAN)
+    assert_series_equal(expected, result, obj="Compare series nan")
+
+    expected = pd.Series([-1.0, 1.0, 0, 1.0], index=dates1)
+    result = compare(x, y, method=Interpolate.ZERO)
+    assert_series_equal(expected, result, obj="Compare series zero")
+
+    expected = pd.Series([-1.0, 1.0, 0, 1.0], index=dates1)
+    result = compare(x, y, method=Interpolate.STEP)
+    assert_series_equal(expected, result, obj="Compare series step")
+
+    dates2 = [
+        date(2019, 1, 2),
+        date(2019, 1, 4),
+        date(2019, 1, 6),
+    ]
+
+    dates1.append(date(2019, 1, 5))
+    xp = pd.Series([1, 2, 3, 4, 5], index=pd.to_datetime(dates1))
+    yp = pd.Series([1, 4, 0], index=pd.to_datetime(dates2))
+    result = compare(xp, yp, Interpolate.TIME)
+    dates1.append(date(2019, 1, 6))
+    expected = pd.Series([0.0, 1.0, 1.0, 0.0, 1.0, 0.0], index=pd.to_datetime(dates1))
+    assert_series_equal(result, expected, obj="Compare series greater time")
+
+
 def test_diff():
     dates = [
         date(2019, 1, 1),
